@@ -17,14 +17,16 @@ def main():
     if args.command == 'push':
         push(args.tenant, args.version, args.config_path,
              args.equal_tags, all_tenants=args.all_tenants, local_version=args.local_version,
-             check_hash=args.check_hash)
+             auto_incr_version=args.auto_incr_version)
     elif args.command == 'rollback':
         rollback(args.tenant, args.version, args.config_path,
-                 args.prev_release, all_tenants=args.all_tenants, local_version=args.local_version)
+                 args.prev_release,
+                 all_tenants=args.all_tenants,
+                 local_version=args.local_version,
+                 delete_all_equal_tags=args.all_tags)
     else:
         raise ValueError('Unknown command. Available push and rollback')
 
 
 if __name__ == "__main__":
     main()
-
